from setuptools import setup, find_packages

setup(
    name="pydiamond",  # ✅ new unique package name for PyPI
    version="1.1.1",
    packages=find_packages(),
    install_requires=[
        "selenium>=4.0.0"
    ],
    author="TaksPy",
    author_email="you@example.com",  # put your real email
    description="PyDiamond - A simple automation language for web bots",
    long_description=open("README.md", encoding="utf-8").read(),
    long_description_content_type="text/markdown",
    url="https://github.com/TaksPy/pydiamond",  # update if repo changes
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Topic :: Software Development :: Libraries",
        "Topic :: Utilities",
    ],
    python_requires=">=3.7",
)
